<?php

namespace Dropwp_Chatfree;

if ( ! defined( 'ABSPATH' ) ) exit;

require_once DROPWP_CHATFREE_PATH . 'includes/lib/class-dropwp-admin.php';
require_once DROPWP_CHATFREE_PATH . 'includes/lib/class-dropwp-helper.php';

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://example.com
 * @since      1.0.0
 *
 * @package    Plugin_Name
 * @subpackage Plugin_Name/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Plugin_Name
 * @subpackage Plugin_Name/admin
 * @author     Your Name <email@example.com>
 */
class Dropwp_Chatfree_Admin extends Dropwp_Admin {

	public function __construct( $plugin_name, $version ) {
		parent::__construct( $plugin_name, $version );
		$this->plugin_dir_url = plugin_dir_url( trim( preg_replace( '@\(.*\(.*$@', '', __FILE__, 1 ) ) );
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {
        parent::enqueue_styles();

        wp_register_style( 'dropwp-chatfree-admin', $this->plugin_dir_url . 'css/dropwp-chatfree-admin.css' );
        wp_enqueue_style( 'dropwp-chatfree-admin' );
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {
        parent::enqueue_scripts();
	}

    /**
	 * Register the stylesheets for the admin area. Only for settings page.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_custom_styles() {
        parent::enqueue_custom_styles();
        wp_enqueue_style( 'jquery-ui-style', $this->plugin_dir_url . 'js/jquery-ui-1.11.4/jquery-ui.min.css' );
        wp_enqueue_style( 'dropwp-chatfree-admin' );
	}

	/**
	 * Register the JavaScript for the admin area. Only for settings page.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_custom_scripts() {
        parent::enqueue_custom_scripts();

        wp_register_script( 'dropwp-chatfree-admin', $this->plugin_dir_url . 'js/dropwp-chatfree-admin.js' );
        wp_enqueue_script( 'jquery-ui-dropwp_chatfree', $this->plugin_dir_url . 'js/jquery-ui-1.11.4/jquery-ui.min.js', false );

        $translation_array = array(
        	'site_url' => get_site_url(),
        );
        wp_localize_script( 'dropwp-chatfree-admin', 'dropwp', $translation_array );
        wp_enqueue_script( 'dropwp-chatfree-admin' );
	}

	/**
	 *
	 * @since 	1.0.0
	 * @access 	public
	 * @return [type] [description]
	 */
	public function callback_settings_page( ) {
		include( DROPWP_CHATFREE_PATH . 'admin/partials/dropwp-chatfree-admin-settings.php' );
	}

    /**
     * Add menu entry.
     *
     * @since    1.0.0
     */
    public function add_menu( ) {
        $page_hook_suffix = add_menu_page (
            __( 'Dropwp Chat Free', 'dropwp_chatfree' ),
            __( 'Dropwp Chat Free', 'dropwp_chatfree' ),
            'manage_options',
            'dropwp-chatfree-settings',
            array( $this, 'callback_settings_page')
        );

        add_action('admin_print_scripts-' . $page_hook_suffix, array( $this, 'enqueue_custom_styles' ) );
        add_action( 'admin_print_styles-' . $page_hook_suffix, array( $this, 'enqueue_custom_scripts' ) );
    }

	/**
	* Register settings
	*/
	public function register_settings () {
		add_settings_section('dropwp_chatfree_settings_config', '', array( $this,'settings_header' ), 'dropwp_chatfree_settings_config');
		$this->add_config( array(
            'page' => 'dropwp_chatfree_settings_config',
            'section' => 'dropwp_chatfree_settings_config',
            'name' => 'dropwp_chatfree_enable',
            'type' => 'checkbox',
            'title' => __( 'Enable', 'dropwp_chatfree' ),
            'help' => __( 'JavaScript code will be included.', 'dropwp_chatfree' ),
        ) );
		$this->add_config( array(
            'page' => 'dropwp_chatfree_settings_config',
            'section' => 'dropwp_chatfree_settings_config',
            'name' => 'dropwp_chatfree_js',
            'type' => 'simple_textarea',
            'title' => __( 'JavaScript code', 'dropwp_chatfree' ),
            'help' => __( 'Live Helper Chat generated JavaScript with configuration.', 'dropwp_chatfree' ),
			'validation' => 'pass_all_validate',
        ) );

	}

	/**
	 * Load and include custom JS
	 * @return [type] [description]
	 */
	public function load_front_js() {
		$js = get_option( 'dropwp_chatfree_js', true );
		$enable = get_option( 'dropwp_chatfree_enable', true );
		if ( $enable && $js ) {
			echo $js;
		}
	}

}
